Skip to contents

Estimates signaling entropy via correlation between gene expression and network connectivity.

Usage

CompCCAT(exp.m, ppiA.m)

Arguments

exp.m

Gene expression matrix (genes x cells). Supports dense or sparse.

ppiA.m

PPI network adjacency matrix (genes x genes).

Value

Numeric vector of CCAT scores (one per cell). Higher values indicate higher differentiation potency.

Details

CCAT computes the Pearson correlation between gene expression and network degree (number of interaction partners) for each cell. This approximation is based on the observation that pluripotent cells express hub genes at higher levels.

The method automatically applies log2(x+1) transformation if the input appears to be raw counts (max > 50).

References

Teschendorff AE, Enver T. Nat Commun. 2017;8:15599.

Author

Andrew E Teschendorff, Zaoqu Liu

Examples

if (FALSE) { # \dontrun{
data(net13Jun12.m)
exp <- matrix(rpois(5000 * 100, 5), nrow = 5000)
rownames(exp) <- head(rownames(net13Jun12.m), 5000)
ccat <- CompCCAT(exp, net13Jun12.m)
} # }